@@ -12,7 +12,7 @@
 #include "xsimd_align.hpp"
 
 #define XSIMD_VERSION_MAJOR 7
-#define XSIMD_VERSION_MINOR 0
+#define XSIMD_VERSION_MINOR 1
 #define XSIMD_VERSION_PATCH 0
 
 #ifndef XSIMD_DEFAULT_ALLOCATOR
@@ -27,4 +27,10 @@
     #define XSIMD_STACK_ALLOCATION_LIMIT 20000
 #endif
 
+#if defined(__LP64__) || defined(_WIN64)
+    #define XSIMD_64_BIT_ABI
+#else
+    #define XSIMD_32_BIT_ABI
+#endif
+
 #endif
