@@ -118,6 +118,7 @@ namespace xsimd
         }
 
         XSIMD_DECLARE_LOAD_STORE_INT8(int8_t, 32);
+        XSIMD_DECLARE_LOAD_STORE_LONG(int8_t, 32);
     };
 
     template <>
@@ -133,6 +134,7 @@ namespace xsimd
         using base_class::store_unaligned;
 
         XSIMD_DECLARE_LOAD_STORE_INT8(uint8_t, 32);
+        XSIMD_DECLARE_LOAD_STORE_LONG(uint8_t, 32);
     };
 
     batch<int8_t, 32> operator<<(const batch<int8_t, 32>& lhs, int32_t rhs);
@@ -411,6 +413,7 @@ namespace xsimd
     }
 
     XSIMD_DEFINE_LOAD_STORE_INT8(int8_t, 32, 32);
+    XSIMD_DEFINE_LOAD_STORE_LONG(int8_t, 32, 32)
 
     inline batch<uint8_t, 32> operator<<(const batch<uint8_t, 32>& lhs, int32_t rhs)
     {
@@ -427,6 +430,7 @@ namespace xsimd
     }
 
     XSIMD_DEFINE_LOAD_STORE_INT8(uint8_t, 32, 32);
+    XSIMD_DEFINE_LOAD_STORE_LONG(uint8_t, 32, 32)
 }
 
 #endif
