@@ -46,6 +46,7 @@ namespace xsimd
         operator simd_type() const;
 
         XSIMD_DECLARE_LOAD_STORE_ALL(double, 2);
+        XSIMD_DECLARE_LOAD_STORE_LONG(double, 2);
 
         using base_type::load_aligned;
         using base_type::load_unaligned;
@@ -211,6 +212,8 @@ namespace xsimd
         return load_aligned(d);
     }
 
+    XSIMD_DEFINE_LOAD_STORE_LONG(double, 2, 16)
+
     inline batch<double, 2>& batch<double, 2>::load_aligned(const float* d)
     {
         m_value = vcvt_f64_f32(vld1_f32(d));
@@ -482,7 +485,7 @@ namespace xsimd
 
             static batch_type bitwise_andnot(const batch_type& lhs, const batch_type& rhs)
             {
-                return vreinterpretq_f32_u64(vbicq_u64(vreinterpretq_u64_f64(lhs), vreinterpretq_u64_f64(rhs)));
+                return vreinterpretq_f64_u64(vbicq_u64(vreinterpretq_u64_f64(lhs), vreinterpretq_u64_f64(rhs)));
             }
 
             static batch_type min(const batch_type& lhs, const batch_type& rhs)
